# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.5.2](https://github.com/denehoffman/laddu/compare/laddu-amplitudes-v0.5.1...laddu-amplitudes-v0.5.2) - 2025-04-11

### Other

- complete compatibility with newest version of bincode, remove unused dependencies and features across all crates

## [0.5.1](https://github.com/denehoffman/laddu/compare/laddu-amplitudes-v0.5.0...laddu-amplitudes-v0.5.1) - 2025-04-04

### Other

- fix some citations and equations, and add phase_space to the API listing

## [0.4.2](https://github.com/denehoffman/laddu/compare/laddu-amplitudes-v0.4.1...laddu-amplitudes-v0.4.2) - 2025-03-13

### Other

- ignore excessive precision warnings

## [0.4.1](https://github.com/denehoffman/laddu/compare/laddu-amplitudes-v0.4.0...laddu-amplitudes-v0.4.1) - 2025-03-04

### Added

- add `PhaseSpaceFactor` amplitude

## [0.4.0](https://github.com/denehoffman/laddu/compare/laddu-amplitudes-v0.3.0...laddu-amplitudes-v0.3.1) - 2025-02-28

### Added

- redefine eps->aux in `Event` definition

## [0.3.0](https://github.com/denehoffman/laddu/compare/laddu-amplitudes-v0.2.5...laddu-amplitudes-v0.3.0) - 2025-02-21

### Other

- update all documentation to include MPI modules
- add some clippy lints and clean up some unused imports and redundant code

## [0.2.5](https://github.com/denehoffman/laddu/compare/laddu-amplitudes-v0.2.4...laddu-amplitudes-v0.2.5) - 2025-01-28

### Other

- updated the following local packages: laddu-core, laddu-python

## [0.2.4](https://github.com/denehoffman/laddu/compare/laddu-amplitudes-v0.2.3...laddu-amplitudes-v0.2.4) - 2025-01-27

### Other

- updated the following local packages: laddu-core, laddu-python

## [0.2.3](https://github.com/denehoffman/laddu/compare/laddu-amplitudes-v0.2.2...laddu-amplitudes-v0.2.3) - 2025-01-24

### Other

- updated the following local packages: laddu-core
